[Bf-blender-cvs] [335e1b507b1] master: Cleanup: BKE b-bone API naming

Campbell Barton noreply at git.blender.org
Sun Dec 2 04:30:46 CET 2018


Commit: 335e1b507b1ad0e7c2bafb2175dac15d3d1add83
Author: Campbell Barton
Date:   Sun Dec 2 14:29:54 2018 +1100
Branches: master
https://developer.blender.org/rB335e1b507b1ad0e7c2bafb2175dac15d3d1add83

Cleanup: BKE b-bone API naming

Use BKE_pchan_bbone prefix.

===================================================================

M	source/blender/blenkernel/BKE_armature.h
M	source/blender/blenkernel/intern/armature.c
M	source/blender/blenkernel/intern/constraint.c
M	source/blender/editors/armature/armature_skinning.c
M	source/blender/editors/space_view3d/drawarmature.c

===================================================================

diff --git a/source/blender/blenkernel/BKE_armature.h b/source/blender/blenkernel/BKE_armature.h
index dea5afa1ac2..efd665b070a 100644
--- a/source/blender/blenkernel/BKE_armature.h
+++ b/source/blender/blenkernel/BKE_armature.h
@@ -139,7 +139,7 @@ typedef struct Mat4 {
 } Mat4;
 
 void equalize_bbone_bezier(float *data, int desired);
-void b_bone_spline_setup(struct bPoseChannel *pchan, int rest, Mat4 result_array[MAX_BBONE_SUBDIV]);
+void BKE_pchan_bbone_spline_setup(struct bPoseChannel *pchan, int rest, Mat4 result_array[MAX_BBONE_SUBDIV]);
 
 /* like EBONE_VISIBLE */
 #define PBONE_VISIBLE(arm, bone) ( \
diff --git a/source/blender/blenkernel/intern/armature.c b/source/blender/blenkernel/intern/armature.c
index 4ad9e9c8205..0f9c79c5e3e 100644
--- a/source/blender/blenkernel/intern/armature.c
+++ b/source/blender/blenkernel/intern/armature.c
@@ -443,7 +443,7 @@ void equalize_bbone_bezier(float *data, int desired)
 
 /* returns pointer to static array, filled with desired amount of bone->segments elements */
 /* this calculation is done  within unit bone space */
-void b_bone_spline_setup(bPoseChannel *pchan, int rest, Mat4 result_array[MAX_BBONE_SUBDIV])
+void BKE_pchan_bbone_spline_setup(bPoseChannel *pchan, int rest, Mat4 result_array[MAX_BBONE_SUBDIV])
 {
 	bPoseChannel *next, *prev;
 	Bone *bone = pchan->bone;
@@ -734,8 +734,8 @@ static void pchan_b_bone_defmats(bPoseChannel *pchan, bPoseChanDeform *pdef_info
 	DualQuat *b_bone_dual_quats = NULL;
 	int a;
 
-	b_bone_spline_setup(pchan, 0, b_bone);
-	b_bone_spline_setup(pchan, 1, b_bone_rest);
+	BKE_pchan_bbone_spline_setup(pchan, 0, b_bone);
+	BKE_pchan_bbone_spline_setup(pchan, 1, b_bone_rest);
 
 	/* allocate b_bone matrices and dual quats */
 	b_bone_mats = MEM_mallocN((1 + bone->segments) * sizeof(Mat4), "BBone defmats");
diff --git a/source/blender/blenkernel/intern/constraint.c b/source/blender/blenkernel/intern/constraint.c
index 66147c44352..6fa0224e3ca 100644
--- a/source/blender/blenkernel/intern/constraint.c
+++ b/source/blender/blenkernel/intern/constraint.c
@@ -586,7 +586,7 @@ static void constraint_target_to_mat4(Object *ob, const char *substring, float m
 				float loc[3], fac;
 
 				/* get bbone segments */
-				b_bone_spline_setup(pchan, 0, bbone);
+				BKE_pchan_bbone_spline_setup(pchan, 0, bbone);
 
 				/* figure out which segment(s) the headtail value falls in */
 				fac = (float)pchan->bone->segments * headtail;
diff --git a/source/blender/editors/armature/armature_skinning.c b/source/blender/editors/armature/armature_skinning.c
index 8ab8d60af75..474e25f8067 100644
--- a/source/blender/editors/armature/armature_skinning.c
+++ b/source/blender/editors/armature/armature_skinning.c
@@ -322,7 +322,7 @@ static void add_verts_to_dgroups(ReportList *reports, Scene *scene, Object *ob,
 				if ((par->pose) && (pchan = BKE_pose_channel_find_name(par->pose, bone->name))) {
 					if (bone->segments > 1) {
 						segments = bone->segments;
-						b_bone_spline_setup(pchan, 1, bbone_array);
+						BKE_pchan_bbone_spline_setup(pchan, 1, bbone_array);
 						bbone = bbone_array;
 					}
 				}
diff --git a/source/blender/editors/space_view3d/drawarmature.c b/source/blender/editors/space_view3d/drawarmature.c
index ec15725d635..0c3b1a21f71 100644
--- a/source/blender/editors/space_view3d/drawarmature.c
+++ b/source/blender/editors/space_view3d/drawarmature.c
@@ -1092,7 +1092,7 @@ static void draw_line_bone(int armflag, int boneflag, short constflag, unsigned
 	glPopMatrix();
 }
 
 /* A partial copy of b_bone_spline_setup(), with just the parts for previewing editmode curve settings
  *
  * This assumes that prev/next bones don't have any impact (since they should all still be in the "straight"
  * position here anyway), and that we can simply apply the bbone settings to get the desired effect...
@@ -1181,7 +1181,7 @@ static void draw_b_bone_boxes(const short dt, bPoseChannel *pchan, EditBone *ebo
 		int a;
 
 		if (pchan) {
-			b_bone_spline_setup(pchan, 0, bbone);
+			BKE_pchan_bbone_spline_setup(pchan, 0, bbone);
 		}
 		else if (ebone) {
 			ebone_spline_preview(ebone, bbone);
@@ -1328,7 +1328,7 @@ static void draw_wire_bone(const short dt, int armflag, int boneflag, short cons
 		length = pchan->bone->length;
 
 		if (segments > 1) {
-			b_bone_spline_setup(pchan, 0, bbones_array);
+			BKE_pchan_bbone_spline_setup(pchan, 0, bbones_array);
 			bbones = bbones_array;
 		}
 	}
@@ -1092,7 +1092,7 @@ static void draw_line_bone(int armflag, int boneflag, short constflag, unsigned
 }
 
-/* A partial copy of b_bone_spline_setup(), with just the parts for previewing editmode curve settings
+/* A partial copy of BKE_pchan_bbone_spline_setup(), with just the parts for previewing editmode curve settings
  *
  * This assumes that prev/next bones don't have any impact (since they should all still be in the "straight"



More information about the Bf-blender-cvs mailing list